@@ -45,7 +45,7 @@ class Job:
     :param name: Job name
     :param source: Source path
     :param destination: Destination path
-    :param period: Min duration between two backups 
+    :param period: Min duration between two backups (in seconds)
     :param snapshot: Activate snapshots (Boolean)
     :param duration: How many days snapshots are kept
     :param keep: How many snapshots are (at least) kept
@@ -113,9 +113,11 @@ class Job:
         :raises TARGETError: if low disk space
         """
         if self.dest_type == 'DIR':
-            if psutil.disk_usage(self.destination)[2] < utils.get_folder_size(self.source):
-                self.logger.critical("Low disk space: %s", self.destination)
-                raise TARGETError('Low disk space on %s' % self.destination)
+            #TODO, change the criterion
+            pass
+            #if psutil.disk_usage(self.destination)[2] < utils.get_folder_size(self.source): 
+            #    self.logger.critical("Low disk space: %s", self.destination)
+            #    raise TARGETError('Low disk space on %s' % self.destination)
         elif self.dest_type == 'SSH':
             #TODO
             pass
@@ -184,14 +186,12 @@ class Job:
             file_date = datetime.datetime.fromtimestamp(os.path.getmtime(filepath[1]))
             if datetime.datetime.now() - file_date > datetime.timedelta(days=days): 
                 self.logger.info("remove %s", filepath[1])
-                shutil.rmtree(filepath[1]) #FIXME: raise something?
-                #try:
-                #    os.remove(filepath[1])
-                #except OSError:
-                #    self.logger.warn("Impossible to remove %s", filepath[1])
-
+                try:
+                    shutil.rmtree(filepath[1])
+                except OSError:
+                    self.logger.error("Impossible to delete %s (symlink?)", filepath[1])
             else:
-                self.logger.debug("keep %s", filepath[1])
+                self.logger.debug("Keep backup %s", filepath[1])
                 return
 
     def _get_last_backup(self, path):
@@ -210,7 +210,7 @@ class Job:
             return None
         return filenames[-1] 
 
-    def _prepare_destination2(self): 
+    def _prepare_destination(self): 
         """
         Prepare the destination to receive a backup:
         * create dirs
@@ -220,22 +220,27 @@ class Job:
         self.current_backup_path = None
 
         if self.dest_type != 'SSH':
+            last_date = self._get_last_backup(os.path.join(self.destination, self.name))
+            self.current_backup_path = os.path.join(self.destination , self.name, str(self.current_date))
+            if last_date is None:
+                #It means that this is the first backup.
+                self.previous_backup_path = None
+            else:
+                self.previous_backup_path = os.path.join(self.destination, self.name, str(last_date))
+
             if self.snapshot:
-                last_date = self._get_last_backup(os.path.join(self.destination, self.name))
-                if last_date is None:
-                    #It means that this is the first backup.
-                    self.previous_backup_path = None
-                else:
-                    self.previous_backup_path = os.path.join(self.destination, self.name, str(last_date))
-                self.current_backup_path = os.path.join(self.destination , self.name, str(self.current_date))
                 os.makedirs(self.current_backup_path) #This one does not exist!
             else:
-                self.current_backup_path = os.path.join(self.destination, self.name)
-                try:
-                    os.makedirs(self.current_backup_path) #This one may exist!
-                except OSError:
-                    #they could already exist
-                    pass
+                if self.previous_backup_path is None:
+                    #Create dir
+                    try:
+                        os.makedirs(self.current_backup_path) #This one may exist!
+                    except OSError:
+                        #they could already exist
+                        pass
+                else:
+                    #Move dir
+                    os.rename(self.previous_backup_path, self.current_backup_path)
         else:
             # Create dirs on the server
             login, dest_dir_path = destination.split(':')
@@ -259,7 +264,7 @@ class Job:
         self.logger.debug("Current backup path: %s", self.current_backup_path)
 
 
-    def _prepare_rsync_command2(self): 
+    def _prepare_rsync_command(self): 
         """
         Compose the rsync command
         """
@@ -325,7 +330,7 @@ class Job:
         """ 
         Run rsync to do the task.
         """
-        command = self._prepare_rsync_command2()
+        command = self._prepare_rsync_command()
 
         #If a signal is received, stop the process
         #if self.terminate: return
@@ -350,7 +355,7 @@ class Job:
             print(self.name)
             self.logger.info("Backup %s", self.name)
             #Prepare the destination
-            self._prepare_destination2()
+            self._prepare_destination()
             self.logger.debug("source path %s", self.source) 
             self.logger.debug("destination path %s", self.destination) 
             self.logger.debug("filter path %s", self.filter)
@@ -371,5 +376,7 @@ class Job:
                 os.symlink(self.current_backup_path, last)
             except FileExistsError:
                 self.logger.warn('The symlink %s could not be created because a file exists', last)
+            except AttributeError:
+                self.logger.warn('Attribute error for symlink') #FIXME
 
 
